<?php

/**
 *  @file
 *  The administration page for the Game Queue module.
 *  @TODO Add game clock default.
 */

/**
 *  Callback for admin/settings/game_queue.
 */
function game_queue_settings_form() {
  $form = array();

  $form[game_queue_variable_name('initiative')] = array(
    '#type' => 'textfield',
    '#title' => t('Default character initiative'),
    '#description' => t('Actions will be processed in a single turn in ascending order of initiative, with all characters having a chance to process a turn before running through the initiative again. The default initiative will be figured for each character each turn, and may be altered by other modules. You may use either a number or dice notation here, such as 1d10 (for a random number of 1-10) or 3d6 (for 3-18).'),
    '#default_value' => game_queue_variable_get('initiative'),
  );
  $form[game_queue_variable_name('available_ap')] = array(
    '#type' => 'textfield',
    '#title' => t('Default character available action points (AP)'),
    '#description' => t('Actions require a certain number of action points (AP) before they may be processed. Some actions may require more points than are available for a character that turn, in which case it will be processed in the next or a later turn. Specify the default number of action points available to a character here. You may use either a number or dice notation here, such as 1d10 (for a random number of 1-10) or 3d6 (for 3-18).'),
    '#default_value' => game_queue_variable_get('available_ap'),
  );

  $form[game_queue_variable_name('character_objects')] = array(
    '#type' => 'radios',
    '#title' => t('Game objects'),
    '#options' => array('user' => t('Users'), 'node' => t('Nodes')),
    '#default_value' => game_queue_variable_get('character_objects'),
    '#required' => TRUE,
    '#description' => t('This determines what type of Drupal objects are used for game characters when adding actions, for purposes of storing actions in the database. It is important not to change this value lightly, as the tables will become disassociated with the current game state. If you do change the value in-game, you should also clear all game actions. If set as Users, then the default character when messaging will be the logged in user for the current page load. If set as Nodes, then the default character will be the active character node, assuming the !game_character module is installed and enabled.', array('!game_character' => l(t('Game Utilities: Character Node'), 'http://drupal.org/project/game_character'))),
  );

  if (game_queue_variable_name('character_objects') == 'node' && (!module_exists('game_character'))) {
    drupal_set_message('You may wish to consider installing and enabling the !game_character module, which will automatically work in conjunction with the game messaging system when using node types as game character types.', array('!game_character' => l(t('Game Utilities: Character Node'), 'http://drupal.org/project/game_character')));
  }

  $form[game_queue_variable_name('debug')] = array(
    '#type' => 'checkbox',
    '#title' => t('Debug'),
    '#description' => t('If checked, then add a debug message when adding actions.'),
    '#default_value' => game_queue_variable_get('debug'),
  );

  return system_settings_form($form);
}

function game_queue_admin_list() {
  $header = array(
    array(
      'data' => t('Action ID'),
      'field' => 'aid',
    ),
    array(
      'data' => t('Character'),
      'field' => 'oid',
    ),
    array(
      'data' => t('Game clock'),
      'field' => 'cid',
    ),
    array(
      'data' => t('Action'),
      'field' => 'action',
    ),
    array(
      'data' => t('Timestamp'),
      'field' => 'timestamp',
    ),
    array(
      'data' => t('Turn'),
      'field' => 'turn',
    ),
    array(
      'data' => t('Action points'),
      'field' => 'ap',
    ),
  );
  $rows = array();

  $sql = "SELECT aid, oid, cid, action, timestamp, turn, ap FROM {game_queue}";
  $tablesort = tablesort_sql($header);
  $result = pager_query($sql . $tablesort, 50);

  while ($row = db_fetch_array($result)) {
    switch(game_queue_variable_get('character_objects')) {
      case 'user':
        $account = user_load(array('uid' => $row['oid']));
        $object_link = l($account->name, 'user/'. $account->uid);
        break;
      case 'node':
        $node = node_load(array('nid' => $row['oid']));
        $object_link = l($node->title, 'node/'. $node->nid);
        break;
    }
    $rows[] = array(
      l($row['aid'], 'admin/settings/game_queue/action/'. $row['aid'] .'/edit'),
      $object_link,
      l($row['cid'], 'admin/settings/game_clock/'. $row['cid']),
      check_plain($row['action']),
      $row['timestamp'],
      $row['turn'],
      $row['ap'],
    );
  }
  $attributes = array();
  $caption = t('Game actions');
  return theme('table', $header, $rows, $attributes, $caption);
}
