<?php

/**
 * @file game_queue/includes/game_queue.create.inc
 *
 * Define the page callback for game-queue.
 */

/**
 *  This is the page callback for game-queue/%action.
 *
 *  This will create a new action object and add it the queue.
 *  If $_GET['js'] is TRUE, it will return an AJAX message.
 *  Otherwise it will display a message.
 *  If $_GET['destination'] is set, it will redirect afterwards.
 */
function game_queue_create_action_page() { //$action, $oid = NULL, $clock = NULL, $turn = NULL, $ap = 1) {
  if (!isset($_GET['action']) || !isset($_GET['context'])) {
    return drupal_not_found();
  }

  $oid = isset($_GET['oid']) ? $_GET['oid'] : game_character_get_active();
  $clock = isset($_GET['clock']) ? $_GET['clock'] : game_queue_variable_get('default_clock');
  $clock = game_clock_load($clock);
  $turn = isset($_GET['turn']) ? $_GET['turn'] : game_clock_current_turn($clock);
  $action = game_queue_actions($_GET['context'], $_GET['action']);
  $action['oid'] = $oid;
  $action['cid'] = $clock->cid;
  $action['turn'] = $turn;
  $action['message'] = game_queue_variable_get('default_action_set_message');
  $action = (object)$action;

  if (!game_queue_create_action_access($action)) {
    drupal_access_denied();
    return;
  }

  // Add the action to the game queue for later processing.
  // Note that this also invokes hook_game_queue_action_alter, allowing
  // modules to add options or whatever.
  game_queue_add_action($action);

  // Make sure the resulting message is safe for display. As it's meant to be
  // set by administrators, we assume it may have full markup.
  // If other modules modify the message, we leave it up to them to do any
  // other necessary filtering.
  $message = filter_xss($action->message);

  // If this is an AJAX callback, then return the string.
  if ($_GET['js']) {
    return drupal_to_js($message);
  }
  else {
    drupal_set_message($message);
  }
  if ($destination = $_GET['destination']) {
    drupal_goto($destination);
  }

  // Display a default 'action set' page.
  return theme('game_queue_create_action_page', $message);
}
